.. pyvipr documentation master file, created by
   sphinx-quickstart on Mon Dec  3 13:26:00 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pyvipr's documentation!
=======================================
pyvipr is an ipython widget for interactively visualizing systems biology models. It uses
`PySB`_ for generating network data and simulating trajectories and `Cytoscape.js`_ to render them.
It supports BioNetGen and SBML models through the pysb importer module.

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   installation
   pysb_tutorial.ipynb
   tellurium_examples.ipynb
   graph_formats_example.ipynb
   modules/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _PySB: http://pysb.org/
.. _Cytoscape.js: http://js.cytoscape.org/